==> localnews-user-service-1.0.3-sources.jar: com/bxm/localnews/user/service/impl/UserAmountServiceImpl.java <==
package com.bxm.localnews.user.service.impl;

import java.math.BigDecimal;

import com.bxm.localnews.user.service.UserAccountService;
import com.bxm.localnews.user.service.UserAmountService;
import com.bxm.localnews.user.vo.UserAccount;
import com.bxm.localnews.user.vo.UserAmount;
import com.bxm.newidea.component.service.BaseService;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * Created by Administrator on 2018/2/23.
 */
@Deprecated
@Service("userAmountService")
public class UserAmountServiceImpl extends BaseService implements UserAmountService {

    @Autowired
    private UserAccountService userAccountService;

    @Override
    public UserAmount findAmountByUserId(Long userId) {
        UserAccount userAccount = userAccountService.getUserAccountDetail(userId);
        return convertUserAccount(userAccount);
    }

    /**
     * 转换账户信息
     *
     * @param userAccount
     * @return
     */
    private UserAmount convertUserAccount(UserAccount userAccount) {
        UserAmount userAmount = new UserAmount();
        userAmount.setId(userAccount.getId());
        userAmount.setUserId(userAccount.getUserId());
        userAmount.setState(userAccount.getState());
        userAmount.setJbBalance(BigDecimal.valueOf(userAccount.getUsableGold()));
        userAmount.setTotalJbBalance(BigDecimal.valueOf(userAccount.getTotalGold()));
        userAmount.setRmbBalance(userAccount.getTempCash().add(userAccount.getStabilizeCash())
                .add(userAccount.getDrawablelCash()));
        userAmount.setTotalRmbBalance(userAccount.getTotalCash());
        userAmount.setUdpateTime(userAccount.getModifyTime());
        return userAmount;
    }
}

==> localnews-user-service-1.0.8-sources.jar: com/bxm/localnews/user/service/impl/UserAmountServiceImpl.java <==
package com.bxm.localnews.user.service.impl;

import java.math.BigDecimal;

import com.bxm.localnews.user.service.UserAccountService;
import com.bxm.localnews.user.service.UserAmountService;
import com.bxm.localnews.user.vo.UserAccount;
import com.bxm.localnews.user.vo.UserAmount;
import com.bxm.newidea.component.service.BaseService;

import org.springframework.stereotype.Service;

import javax.annotation.Resource;

/**
 * Created by Administrator on 2018/2/23.
 */
@Deprecated
@Service("userAmountService")
public class UserAmountServiceImpl extends BaseService implements UserAmountService {

    @Resource
    private UserAccountService userAccountService;

    @Override
    public UserAmount findAmountByUserId(Long userId) {
        UserAccount userAccount = userAccountService.getUserAccountDetail(userId);
        return convertUserAccount(userAccount);
    }

    /**
     * 转换账户信息
     *
     * @param userAccount
     * @return
     */
    private UserAmount convertUserAccount(UserAccount userAccount) {
        UserAmount userAmount = new UserAmount();
        userAmount.setId(userAccount.getId());
        userAmount.setUserId(userAccount.getUserId());
        userAmount.setState(userAccount.getState());
        userAmount.setJbBalance(BigDecimal.valueOf(userAccount.getUsableGold()));
        userAmount.setTotalJbBalance(BigDecimal.valueOf(userAccount.getTotalGold()));
        userAmount.setRmbBalance(userAccount.getTempCash().add(userAccount.getStabilizeCash())
                .add(userAccount.getDrawablelCash()));
        userAmount.setTotalRmbBalance(userAccount.getTotalCash());
        userAmount.setUdpateTime(userAccount.getModifyTime());
        return userAmount;
    }
}
